==> toolbox-0.1-source-release.zip: toolbox-0.1/README.md <==
<!--
{% comment %}
Licensed to Julian Hyde under one or more contributor license
agreements.  See the NOTICE file distributed with this work for
additional information regarding copyright ownership. Julian Hyde
licenses this file to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance with the
License.  You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
{% endcomment %}
-->
[![Build Status](https://travis-ci.org/julianhyde/toolbox.png)](https://travis-ci.org/julianhyde/toolbox)

# Toolbox

A collection of miscellaneous utilities.

## Prerequisites

Toolbox requires Java (1.7 or higher; 1.8 preferred), git, maven (3.2.1 or higher).

## Get Toolbox

### From Maven

Get Toolbox from
<a href="https://search.maven.org/#search%7Cga%7C1%7Cg%3Anet.hydromatic%20a%3Atoolbox">Maven central</a>:

```xml
<dependency>
  <groupId>net.hydromatic</groupId>
  <artifactId>toolbox</artifactId>
  <version>0.1</version>
</dependency>
```

### Download and build

```bash
$ git clone git://github.com/julianhyde/toolbox.git
$ cd toolbox
$ mvn install
```

## More information

* License: Apache License, Version 2.0
* Author: Julian Hyde
* Blog: http://julianhyde.blogspot.com
* Project page: http://www.hydromatic.net/toolbox
* Source code: http://github.com/julianhyde/toolbox
* Developers list:
  <a href="mailto:dev@calcite.apache.org">dev at calcite.apache.org</a>
  (<a href="http://mail-archives.apache.org/mod_mbox/calcite-dev/">archive</a>,
  <a href="mailto:dev-subscribe@calcite.apache.org">subscribe</a>)
* Issues: https://github.com/julianhyde/toolbox/issues
* <a href="HISTORY.md">Release notes and history</a>

==> toolbox-0.3-source-release.zip: toolbox-0.3/README.md <==
<!--
{% comment %}
Licensed to Julian Hyde under one or more contributor license
agreements.  See the NOTICE file distributed with this work for
additional information regarding copyright ownership. Julian Hyde
licenses this file to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance with the
License.  You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
{% endcomment %}
-->
[![Build Status](https://travis-ci.org/julianhyde/toolbox.png)](https://travis-ci.org/julianhyde/toolbox)

# Toolbox

A collection of miscellaneous utilities.

## Prerequisites

Toolbox requires Java (1.7 or higher; 1.8 preferred), git, maven (3.2.1 or higher).

## Get Toolbox

### From Maven

Get Toolbox from
<a href="https://search.maven.org/#search%7Cga%7C1%7Cg%3Anet.hydromatic%20a%3Atoolbox">Maven Central</a>:

```xml
<dependency>
  <groupId>net.hydromatic</groupId>
  <artifactId>toolbox</artifactId>
  <version>0.3</version>
</dependency>
```

### Download and build

```bash
$ git clone git://github.com/julianhyde/toolbox.git
$ cd toolbox
$ mvn install
```

## More information

* License: Apache License, Version 2.0
* Author: Julian Hyde
* Blog: http://julianhyde.blogspot.com
* Project page: http://www.hydromatic.net/toolbox
* Source code: http://github.com/julianhyde/toolbox
* Developers list:
  <a href="mailto:dev@calcite.apache.org">dev at calcite.apache.org</a>
  (<a href="http://mail-archives.apache.org/mod_mbox/calcite-dev/">archive</a>,
  <a href="mailto:dev-subscribe@calcite.apache.org">subscribe</a>)
* Issues: https://github.com/julianhyde/toolbox/issues
* <a href="HISTORY.md">Release notes and history</a>
